summaryrefslogtreecommitdiffstats
path: root/src/plugins
diff options
context:
space:
mode:
authorDmytro Poplavskiy <dmytro.poplavskiy@nokia.com>2011-06-10 14:50:33 +1000
committerQt by Nokia <qt-info@nokia.com>2011-07-05 06:49:30 +0200
commite94afd6cf2004c7d5ece6fe15e4298560079c353 (patch)
treefbd6178c57a1634e36410a3cb51667af38795e62 /src/plugins
parent843f47fc59aa0da114e426b978e5060a0bdabfa1 (diff)
Gst player backend: increased network timeout.
5 seconds timeout is to short, increased to 30 seconds. Task-number: MOBILITY-3013 Reviewed-by: Michael Goddard (cherry picked from commit cf230f948de63c7755c7759b3e14a02ad14cb185) Change-Id: I41d62ac1ed15f2c09af6fd804723096996d16139 Reviewed-on: http://codereview.qt.nokia.com/974 Reviewed-by: Qt Sanity Bot <qt_sanity_bot@ovi.com> Reviewed-by: Michael Goddard
Diffstat (limited to 'src/plugins')
-rw-r--r--src/plugins/gstreamer/mediaplayer/qgstreamerplayersession.cpp9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/plugins/gstreamer/mediaplayer/qgstreamerplayersession.cpp b/src/plugins/gstreamer/mediaplayer/qgstreamerplayersession.cpp
index d12bb2697..ccb84d15a 100644
--- a/src/plugins/gstreamer/mediaplayer/qgstreamerplayersession.cpp
+++ b/src/plugins/gstreamer/mediaplayer/qgstreamerplayersession.cpp
@@ -1417,18 +1417,19 @@ void QGstreamerPlayerSession::playbinNotifySource(GObject *o, GParamSpec *p, gpo
gst_structure_free(extras);
}
- //set timeout property to 5 seconds
+ //set timeout property to 30 seconds
+ const int timeout = 30;
if (qstrcmp(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(source)), "GstUDPSrc") == 0) {
//udpsrc timeout unit = microsecond
- g_object_set(G_OBJECT(source), "timeout", G_GUINT64_CONSTANT(5000000), NULL);
+ g_object_set(G_OBJECT(source), "timeout", G_GUINT64_CONSTANT(timeout*1000000), NULL);
self->m_sourceType = UDPSrc;
} else if (qstrcmp(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(source)), "GstSoupHTTPSrc") == 0) {
//souphttpsrc timeout unit = second
- g_object_set(G_OBJECT(source), "timeout", guint(5), NULL);
+ g_object_set(G_OBJECT(source), "timeout", guint(timeout), NULL);
self->m_sourceType = SoupHTTPSrc;
} else if (qstrcmp(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(source)), "GstMMSSrc") == 0) {
self->m_sourceType = MMSSrc;
- g_object_set(G_OBJECT(source), "tcp-timeout", G_GUINT64_CONSTANT(5000000), NULL);
+ g_object_set(G_OBJECT(source), "tcp-timeout", G_GUINT64_CONSTANT(timeout*1000000), NULL);
} else {
self->m_sourceType = UnknownSrc;
}